****
* A Biological Model of Unions
* Michael Kremer and Benjamin A. Olken
* This file produces Table 1, Table 2 and Figure 2 in the paper
* The file uses Stata version 9.2
***



version 9.2
clear
set mem 10m



**************
* Table 1 and Figure 2
* Uses data on union constitutions
**************

***
use unions_data_aej,clear

for var m*: g lX = ln(X)
g growth = ln(m1995) - ln(m1955)

/*for unions whose 1995 or 1955 growth is missing, use other years*/
replace growth = (ln(m1995) - ln(m1965))*4/3 if growth == . & m1995 != . & m1965 != .
replace growth = (ln(m1995) - ln(m1975))*4/2 if growth == . & m1995 != . & m1975 != .
replace growth = (ln(m1995) - ln(m1985))*4 if growth == . & m1995 != . & m1985 != .
replace growth = (ln(m1985) - ln(m1955))*4/3 if growth == . & m1985 != . & m1955 != .
replace growth = (ln(m1975) - ln(m1955))*4/2 if growth == . & m1975 != . & m1955 != .
replace growth = (ln(m1965) - ln(m1955))*4 if growth == . & m1965 != . & m1955 != .

g growthfrac = exp(growth)
replace growthfrac = 0 if alive == 0 & m1995 == .


*g lm1955 = ln(m1955)
*replace growth = m1995 / m1955

g decline = 1 if growth <= ln(0.5)
replace decline = 0 if growth > ln(0.5)
replace decline = 1 if m1995 == 0 | m1995 == . /*you had a decline if you're no longer around*/
g temp1 = 1 if alive == 0 & decline == 0 /*becuase of alive you declined*/
replace decline = 1 if alive == 0 /*experienced a decline or is no longer around*/
pause

g decline25 = decline
replace decline25 = 1 if growth <= ln(0.75) & growth != .

g decline10 = decline
replace decline10 = 1 if growth <= ln(0.9) & growth != .

g decline75 = decline
replace decline75 = 0 if growth > ln(0.25) & growth != . & alive == 1


g votes_strike_authorization = .5 if onlyolddata == 0
replace votes_strike_authorization = vfsa if vfsa!=.


/*restrict to private sector*/
keep if public == 0


***
* Make Figure 2
***

kdensity growth if direct == 0, g(ix iy) nograph
kdensity growth if direct == 1, g(dx dy) nograph
label var iy "Indirect"
label var dy "Direct"
twoway (line iy ix, lpattern(dash)) (line dy dx), saving("Direct-Indirect",replace) 
graph export figure2.eps,replace



***
* Make Table 1
***
tab decline

g dm = direct * m1955
g dlm  = direct * lm1955
g SIC_digit = int(siccode1/10)
g dcio = direct * cio
g votessuper = 1 if votes_strike_authorization > .5 & votes_strike != .
replace votessuper = 0 if votes_strike_authorization == .5 
g superm = votessuper * m1955
g supercio = votessuper * cio
label var votessuper "Supermajority strike vote rule"
label var m1955 "1955 Union Membership (thousands)"


reg decline direct votessuper, robust
outreg using table1, 3aster coefastr se replace title("Constitutions and Union Decline") 
outreg using table15, 3aster coefastr se replace title("Constitutions and Union Decline") bd(5)

reg decline direct votessuper m1955, robust
outreg using table1, 3aster coefastr se append 
outreg using table15, 3aster coefastr se append bd(5)

reg decline direct votessuper m1955 cio, robust
outreg using table1, 3aster coefastr se append 
outreg using table15, 3aster coefastr se append bd(5)

areg decline direct votessuper m1955 cio, robust absorb(SIC)
outreg using table1, 3aster coefastr se append 
outreg using table15, 3aster coefastr se append bd(5)	


**************
* Table 2
* Uses data on turnover by industry
**************

use unions_data_aej_table2,clear

sum amem ext99 ext size hhi k if (amem!=. & ext99!=. & size!=. & hhi!=. & k!=.)

reg amem ext99 [w=w1]
outreg using table2.out, 3aster coefastr se replace title("Union membership")
reg amem ext99 hhi [w=w1]
outreg using table2.out, 3aster coefastr se append
reg amem ext99 size [w=w1]
outreg using table2.out, 3aster coefastr se append
reg amem ext99 k [w=w1]
outreg using table2.out, 3aster coefastr se append
reg amem ext99 hhi size k[w=w1]
outreg using table2.out, 3aster coefastr se append
